pub struct ActiveViewVideoViewabilityMetricConfig {
pub display_name: Option<String>,
pub minimum_duration: Option<String>,
pub minimum_quartile: Option<String>,
pub minimum_viewability: Option<String>,
pub minimum_volume: Option<String>,
}Expand description
Configuration for custom Active View video viewability metrics.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Required. The display name of the custom metric.
minimum_duration: Option<String>The minimum visible video duration required (in seconds) in order for an impression to be recorded. You must specify minimum_duration, minimum_quartile or both. If both are specified, an impression meets the metric criteria if either requirement is met (whichever happens first).
minimum_quartile: Option<String>The minimum visible video duration required, based on the video quartiles, in order for an impression to be recorded. You must specify minimum_duration, minimum_quartile or both. If both are specified, an impression meets the metric criteria if either requirement is met (whichever happens first).
minimum_viewability: Option<String>Required. The minimum percentage of the video ad’s pixels visible on the screen in order for an impression to be recorded.
minimum_volume: Option<String>Required. The minimum percentage of the video ad’s volume required in order for an impression to be recorded.