Struct google_displayvideo1::api::AssignedInventorySource [−][src]
An assignment between a targetable inventory source and an inventory source group.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- assigned inventory sources create inventory source groups (request|response)
Fields
assigned_inventory_source_id: Option<String>Output only. The unique ID of the assigned inventory source. The ID is only unique within a given inventory source group. It may be reused in other contexts.
inventory_source_id: Option<String>Required. The ID of the inventory source entity being targeted.
name: Option<String>Output only. The resource name of the assigned inventory source.