Struct google_displayvideo1::api::AssignedUserRole[][src]

pub struct AssignedUserRole {
    pub advertiser_id: Option<String>,
    pub assigned_user_role_id: Option<String>,
    pub partner_id: Option<String>,
    pub user_role: Option<String>,
}

A single assigned user role, which defines a user’s authorized interaction with a specified partner or advertiser.

This type is not used in any activity, and only used as part of another schema.

Fields

advertiser_id: Option<String>

The ID of the advertiser that the assigend user role applies to.

assigned_user_role_id: Option<String>

Output only. The ID of the assigned user role.

partner_id: Option<String>

The ID of the partner that the assigned user role applies to.

user_role: Option<String>

Required. The user role to assign to a user for the entity.