AudienceGroupAssignedTargetingOptionDetails

Struct AudienceGroupAssignedTargetingOptionDetails 

pub struct AudienceGroupAssignedTargetingOptionDetails {
    pub excluded_google_audience_group: Option<GoogleAudienceGroup>,
    pub included_combined_audience_group: Option<CombinedAudienceGroup>,
    pub included_custom_list_group: Option<CustomListGroup>,
    pub included_google_audience_group: Option<GoogleAudienceGroup>,
}
Assigned audience group targeting option details. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_AUDIENCE_GROUP. The relation between each group is UNION, except for excluded_first_and_third_party_audience_group and excluded_google_audience_group, of which COMPLEMENT is used as an INTERSECTION with other groups.

This type is not used in any activity, and only used as part of another schema.

Fields

excluded_google_audience_group: Option<GoogleAudienceGroup>

Optional. The Google audience ids of the excluded Google audience group. Used for negative targeting. The COMPLEMENT of the UNION of this group and other excluded audience groups is used as an INTERSECTION to any positive audience targeting. Only contains Affinity, In-market and Installed-apps type Google audiences. All items are logically ‘OR’ of each other.

included_combined_audience_group: Option<CombinedAudienceGroup>

Optional. The combined audience ids of the included combined audience group. Contains combined audience ids only.

included_custom_list_group: Option<CustomListGroup>

Optional. The custom list ids of the included custom list group. Contains custom list ids only.

included_google_audience_group: Option<GoogleAudienceGroup>

Optional. The Google audience ids of the included Google audience group. Contains Google audience ids only.