AuditAdvertiserResponse

Struct AuditAdvertiserResponse 

pub struct AuditAdvertiserResponse {
    pub ad_group_criteria_count: Option<i64>,
    pub campaign_criteria_count: Option<i64>,
    pub channels_count: Option<i64>,
    pub negative_keyword_lists_count: Option<i64>,
    pub negatively_targeted_channels_count: Option<i64>,
    pub used_campaigns_count: Option<i64>,
    pub used_insertion_orders_count: Option<i64>,
    pub used_line_items_count: Option<i64>,
}
Response message for AdvertiserService.AuditAdvertiser.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

ad_group_criteria_count: Option<i64>

The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser. These individual targeting options count towards the limit of 4500000 ad group targeting options per advertiser. Qualifying Targeting types: * Channels, URLs, apps, and collections * Demographic * Google Audiences, including Affinity, Custom Affinity, and In-market audiences * Inventory source * Keyword * Mobile app category * User lists * Video targeting * Viewability

campaign_criteria_count: Option<i64>

The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser. These individual targeting options count towards the limit of 900000 campaign targeting options per advertiser. Qualifying Targeting types: * Position * Browser * Connection speed * Day and time * Device and operating system * Digital content label * Sensitive categories * Environment * Geography, including business chains and proximity * ISP * Language * Third-party verification

channels_count: Option<i64>

The number of channels created under this advertiser. These channels count towards the limit of 1000 channels per advertiser.

negative_keyword_lists_count: Option<i64>

The number of negative keyword lists created under this advertiser. These negative keyword lists count towards the limit of 20 negative keyword lists per advertiser.

negatively_targeted_channels_count: Option<i64>

The number of negatively targeted channels created under this advertiser. These negatively targeted channels count towards the limit of 5 negatively targeted channels per advertiser.

used_campaigns_count: Option<i64>

The number of ACTIVE and PAUSED campaigns under this advertiser. These campaigns count towards the limit of 9999 campaigns per advertiser.

used_insertion_orders_count: Option<i64>

The number of ACTIVE, PAUSED and DRAFT insertion orders under this advertiser. These insertion orders count towards the limit of 9999 insertion orders per advertiser.

used_line_items_count: Option<i64>

The number of ACTIVE, PAUSED, and DRAFT line items under this advertiser. These line items count towards the limit of 9999 line items per advertiser.