pub struct BudgetSummary {
pub external_budget_id: Option<String>,
pub pre_tax_amount_micros: Option<i64>,
pub prisma_cpe_code: Option<PrismaCpeCode>,
pub tax_amount_micros: Option<i64>,
pub total_amount_micros: Option<i64>,
}Expand description
Summarized information of an individual campaign budget.
This type is not used in any activity, and only used as part of another schema.
Fields
external_budget_id: Option<String>Corresponds to the external_budget_id of a campaign budget. If the value is not set in the campaign budget, this field will be empty.
pre_tax_amount_micros: Option<i64>The sum of charges made under this budget before taxes, in micros of the invoice’s currency. For example, if currency_code is USD, then 1000000 represents one US dollar.
prisma_cpe_code: Option<PrismaCpeCode>Relevant client, product, and estimate codes from the Mediaocean Prisma tool. Only applicable for campaign budgets with an external_budget_source of EXTERNAL_BUDGET_SOURCE_MEDIA_OCEAN.
tax_amount_micros: Option<i64>The amount of tax applied to charges under this budget, in micros of the invoice’s currency. For example, if currency_code is USD, then 1000000 represents one US dollar.
total_amount_micros: Option<i64>The total sum of charges made under this budget, including tax, in micros of the invoice’s currency. For example, if currency_code is USD, then 1000000 represents one US dollar.