Struct google_displayvideo1::api::BulkEditAssignedInventorySourcesRequest [−][src]
Request message for AssignedInventorySourceService.BulkEdit.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
advertiser_id: Option<String>The ID of the advertiser that owns the parent inventory source group. The parent partner does not have access to these assigned inventory sources.
created_assigned_inventory_sources: Option<Vec<AssignedInventorySource>>The assigned inventory sources to create in bulk, specified as a list of AssignedInventorySources.
deleted_assigned_inventory_sources: Option<Vec<String>>The IDs of the assigned inventory sources to delete in bulk, specified as a list of assigned_inventory_source_ids.
partner_id: Option<String>The ID of the partner that owns the inventory source group. Only this partner has write access to these assigned inventory sources.