pub struct Channel {
pub advertiser_id: Option<i64>,
pub channel_id: Option<i64>,
pub display_name: Option<String>,
pub name: Option<String>,
pub negatively_targeted_line_item_count: Option<i64>,
pub partner_id: Option<i64>,
pub positively_targeted_line_item_count: Option<i64>,
}Expand description
A single channel. Channels are custom groups of related websites and apps.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- channels create advertisers (request|response)
- channels get advertisers (response)
- channels patch advertisers (request|response)
- channels create partners (request|response)
- channels get partners (response)
- channels patch partners (request|response)
Fields
advertiser_id: Option<i64>The ID of the advertiser that owns the channel.
channel_id: Option<i64>Output only. The unique ID of the channel. Assigned by the system.
display_name: Option<String>Required. The display name of the channel. Must be UTF-8 encoded with a maximum length of 240 bytes.
name: Option<String>Output only. The resource name of the channel.
negatively_targeted_line_item_count: Option<i64>Output only. Number of line items that are directly targeting this channel negatively.
partner_id: Option<i64>The ID of the partner that owns the channel.
positively_targeted_line_item_count: Option<i64>Output only. Number of line items that are directly targeting this channel positively.