pub struct CombinedAudienceGroup {
pub settings: Option<Vec<CombinedAudienceTargetingSetting>>,
}Expand description
Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.
This type is not used in any activity, and only used as part of another schema.
Fields
settings: Option<Vec<CombinedAudienceTargetingSetting>>Required. All combined audience targeting settings in combined audience group. Repeated settings with the same id will be ignored. The number of combined audience settings should be no more than five, error will be thrown otherwise.