pub struct ContentInstreamPositionAssignedTargetingOptionDetails {
pub ad_type: Option<String>,
pub content_instream_position: Option<String>,
pub targeting_option_id: Option<String>,
}Expand description
Assigned content instream position targeting option details. This will be populated in the content_instream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
This type is not used in any activity, and only used as part of another schema.
Fields
ad_type: Option<String>Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * AD_TYPE_VIDEO, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_VIDEO_DEFAULT. * AD_TYPE_AUDIO, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_AUDIO_DEFAULT.
content_instream_position: Option<String>Required. The content instream position for video or audio ads.
targeting_option_id: Option<String>Required. The targeting_option_id field when targeting_type is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.