pub struct ContentOutstreamPositionTargetingOptionDetails {
pub content_outstream_position: Option<String>,
}Expand description
Represents a targetable content outstream position, which could be used by display and video ads. This will be populated in the content_outstream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.
This type is not used in any activity, and only used as part of another schema.
Fields
content_outstream_position: Option<String>Output only. The content outstream position.