pub struct CreateSdfDownloadTaskRequest {
pub advertiser_id: Option<i64>,
pub id_filter: Option<IdFilter>,
pub inventory_source_filter: Option<InventorySourceFilter>,
pub parent_entity_filter: Option<ParentEntityFilter>,
pub partner_id: Option<i64>,
pub version: Option<String>,
}Expand description
Request message for [SdfDownloadTaskService.CreateSdfDownloadTask].
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create sdfdownloadtasks (request)
Fields
advertiser_id: Option<i64>The ID of the advertiser to download SDF for.
id_filter: Option<IdFilter>Filters on entities by their entity IDs.
inventory_source_filter: Option<InventorySourceFilter>Filters on Inventory Sources by their IDs.
parent_entity_filter: Option<ParentEntityFilter>Filters on selected file types. The entities in each file are filtered by a chosen set of filter entities. The filter entities must be the same type as, or a parent type of, the selected file types.
partner_id: Option<i64>The ID of the partner to download SDF for.
version: Option<String>Required. The SDF version of the downloaded file. If set to SDF_VERSION_UNSPECIFIED, this will default to the version specified by the advertiser or partner identified by root_id. An advertiser inherits its SDF version from its partner unless configured otherwise.