Struct google_displayvideo1::api::CustomBiddingAlgorithm[][src]

pub struct CustomBiddingAlgorithm {
    pub advertiser_id: Option<String>,
    pub custom_bidding_algorithm_id: Option<String>,
    pub custom_bidding_algorithm_type: Option<String>,
    pub display_name: Option<String>,
    pub entity_status: Option<String>,
    pub name: Option<String>,
    pub partner_id: Option<String>,
}

A single custom bidding algorithm.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

advertiser_id: Option<String>

Immutable. The unique ID of the advertiser that owns the custom bidding algorithm.

custom_bidding_algorithm_id: Option<String>

Output only. The unique ID of the custom bidding algorithm. Assigned by the system.

custom_bidding_algorithm_type: Option<String>

Required. Immutable. The type of custom bidding algorithm.

display_name: Option<String>

Required. The display name of the custom bidding algorithm. Must be UTF-8 encoded with a maximum size of 240 bytes.

entity_status: Option<String>

Controls whether or not the custom bidding algorithm can be used as a bidding strategy. Accepted values are: * ENTITY_STATUS_ACTIVE * ENTITY_STATUS_ARCHIVED

name: Option<String>

Output only. The resource name of the custom bidding algorithm.

partner_id: Option<String>

Immutable. The unique ID of the partner that owns the custom bidding algorithm.