pub struct CustomBiddingScript {
pub active: Option<bool>,
pub create_time: Option<DateTime<Utc>>,
pub custom_bidding_algorithm_id: Option<i64>,
pub custom_bidding_script_id: Option<i64>,
pub errors: Option<Vec<ScriptError>>,
pub name: Option<String>,
pub script: Option<CustomBiddingScriptRef>,
pub state: Option<String>,
}Expand description
A single custom bidding script.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- scripts create custom bidding algorithms (request|response)
- scripts get custom bidding algorithms (response)
Fields
active: Option<bool>Output only. Whether the script is currently being used for scoring by the parent algorithm.
create_time: Option<DateTime<Utc>>Output only. The time when the script was created.
custom_bidding_algorithm_id: Option<i64>Output only. The unique ID of the custom bidding algorithm the script belongs to.
custom_bidding_script_id: Option<i64>Output only. The unique ID of the custom bidding script.
errors: Option<Vec<ScriptError>>Output only. Error details of a rejected custom bidding script. This field will only be populated when state is REJECTED.
name: Option<String>Output only. The resource name of the custom bidding script.
script: Option<CustomBiddingScriptRef>The reference to the uploaded script file.
state: Option<String>Output only. The state of the custom bidding script.