Struct google_displayvideo1::api::CustomList [−][src]
Describes a custom list entity, such as a custom affinity or custom intent audience list.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get custom lists (response)
- list custom lists (none)
Fields
custom_list_id: Option<String>Output only. The unique ID of the custom list. Assigned by the system.
display_name: Option<String>Output only. The display name of the custom list. .
name: Option<String>Output only. The resource name of the custom list.