pub struct CustomListGroup {
pub settings: Option<Vec<CustomListTargetingSetting>>,
}Expand description
Details of custom list group. All custom list targeting settings are logically ‘OR’ of each other.
This type is not used in any activity, and only used as part of another schema.
Fields
settings: Option<Vec<CustomListTargetingSetting>>Required. All custom list targeting settings in custom list group. Repeated settings with the same id will be ignored.