pub struct EditGuaranteedOrderReadAccessorsResponse {
pub read_access_inherited: Option<bool>,
pub read_advertiser_ids: Option<Vec<i64>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
read_access_inherited: Option<bool>Whether all advertisers of read_write_partner_id have read access to the guaranteed order.
read_advertiser_ids: Option<Vec<i64>>The IDs of advertisers with read access to the guaranteed order.