pub struct FrequencyCap {
pub max_impressions: Option<i32>,
pub time_unit: Option<String>,
pub time_unit_count: Option<i32>,
pub unlimited: Option<bool>,
}Expand description
Settings that control the number of times a user may be shown with the same ad during a given time period.
This type is not used in any activity, and only used as part of another schema.
Fields
max_impressions: Option<i32>The maximum number of times a user may be shown the same ad during this period. Must be greater than 0. Required when unlimited is false and max_views is not set.
time_unit: Option<String>The time unit in which the frequency cap will be applied. Required when unlimited is false.
time_unit_count: Option<i32>The number of time_unit the frequency cap will last. Required when unlimited is false. The following restrictions apply based on the value of time_unit: * TIME_UNIT_MONTHS - must be 1 * TIME_UNIT_WEEKS - must be between 1 and 4 * TIME_UNIT_DAYS - must be between 1 and 6 * TIME_UNIT_HOURS - must be between 1 and 23 * TIME_UNIT_MINUTES - must be between 1 and 59
unlimited: Option<bool>Whether unlimited frequency capping is applied. When this field is set to true, the remaining frequency cap fields are not applicable.