pub struct GeoRegionAssignedTargetingOptionDetails {
pub display_name: Option<String>,
pub geo_region_type: Option<String>,
pub negative: Option<bool>,
pub targeting_option_id: Option<String>,
}Expand description
Details for assigned geographic region targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_GEO_REGION.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Output only. The display name of the geographic region (e.g., “Ontario, Canada”).
geo_region_type: Option<String>Output only. The type of geographic region targeting.
negative: Option<bool>Indicates if this option is being negatively targeted.
targeting_option_id: Option<String>Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_GEO_REGION.