pub struct GuaranteedOrderStatus {
pub config_status: Option<String>,
pub entity_pause_reason: Option<String>,
pub entity_status: Option<String>,
}Expand description
The status settings of the guaranteed order.
This type is not used in any activity, and only used as part of another schema.
Fields
config_status: Option<String>Output only. The configuration status of the guaranteed order. Acceptable values are PENDING and COMPLETED. A guaranteed order must be configured (fill in the required fields, choose creatives, and select a default campaign) before it can serve. Currently the configuration action can only be performed via UI.
entity_pause_reason: Option<String>The user-provided reason for pausing this guaranteed order. Must be UTF-8 encoded with a maximum length of 100 bytes. Only applicable when entity_status is set to ENTITY_STATUS_PAUSED.
entity_status: Option<String>Whether or not the guaranteed order is servable. Acceptable values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. Default value is ENTITY_STATUS_ACTIVE.