pub struct IdFilter {
pub ad_group_ad_ids: Option<Vec<i64>>,
pub ad_group_ids: Option<Vec<i64>>,
pub campaign_ids: Option<Vec<i64>>,
pub insertion_order_ids: Option<Vec<i64>>,
pub line_item_ids: Option<Vec<i64>>,
pub media_product_ids: Option<Vec<i64>>,
}Expand description
A filtering option that filters entities by their entity IDs.
This type is not used in any activity, and only used as part of another schema.
Fields
ad_group_ad_ids: Option<Vec<i64>>YouTube Ads to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.
ad_group_ids: Option<Vec<i64>>YouTube Ad Groups to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.
campaign_ids: Option<Vec<i64>>Campaigns to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.
insertion_order_ids: Option<Vec<i64>>Insertion Orders to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.
line_item_ids: Option<Vec<i64>>Line Items to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.
media_product_ids: Option<Vec<i64>>Media Products to download by ID. All IDs must belong to the same Advertiser or Partner specified in CreateSdfDownloadTaskRequest.