pub struct InventorySourceDisplayCreativeConfig {
pub creative_size: Option<Dimensions>,
}Expand description
The configuration for display creatives.
This type is not used in any activity, and only used as part of another schema.
Fields
creative_size: Option<Dimensions>The size requirements for display creatives that can be assigned to the inventory source.