Struct google_displayvideo1::api::LanguageAssignedTargetingOptionDetails [−][src]
Details for assigned language targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_LANGUAGE.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Output only. The display name of the language (e.g., “French”).
negative: Option<bool>Indicates if this option is being negatively targeted. All assigned language targeting options on the same resource must have the same value for this field.
targeting_option_id: Option<String>Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_LANGUAGE.