pub struct ListAdvertiserAssignedTargetingOptionsResponse {
pub assigned_targeting_options: Option<Vec<AssignedTargetingOption>>,
pub next_page_token: Option<String>,
}Expand description
Response message for ListAdvertiserAssignedTargetingOptions.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
assigned_targeting_options: Option<Vec<AssignedTargetingOption>>The list of assigned targeting options. This list will be absent if empty.
next_page_token: Option<String>A token identifying the next page of results. This value should be specified as the pageToken in a subsequent ListAdvertiserAssignedTargetingOptionsRequest to fetch the next page of results. This token will be absent if there are no more assigned_targeting_options to return.