Struct google_displayvideo1::api::ListAssignedInventorySourcesResponse[][src]

pub struct ListAssignedInventorySourcesResponse {
    pub assigned_inventory_sources: Option<Vec<AssignedInventorySource>>,
    pub next_page_token: Option<String>,
}

Response message for AssignedInventorySourceService.ListAssignedInventorySources.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

assigned_inventory_sources: Option<Vec<AssignedInventorySource>>

The list of assigned inventory sources. This list will be absent if empty.

next_page_token: Option<String>

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAssignedInventorySources method to retrieve the next page of results.