pub struct ListCampaignsResponse {
pub campaigns: Option<Vec<Campaign>>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- campaigns list advertisers (response)
Fields
campaigns: Option<Vec<Campaign>>The list of campaigns. This list will be absent if empty.
next_page_token: Option<String>A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCampaigns method to retrieve the next page of results.