pub struct ListNegativeKeywordsResponse {
pub negative_keywords: Option<Vec<NegativeKeyword>>,
pub next_page_token: Option<String>,
}Expand description
Response message for NegativeKeywordService.ListNegativeKeywords.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
negative_keywords: Option<Vec<NegativeKeyword>>The list of negative keywords. This list will be absent if empty.
next_page_token: Option<String>A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListNegativeKeywords method to retrieve the next page of results.