pub struct ManualTrigger {
pub activation_duration_minutes: Option<i64>,
pub advertiser_id: Option<i64>,
pub display_name: Option<String>,
pub latest_activation_time: Option<DateTime<Utc>>,
pub name: Option<String>,
pub state: Option<String>,
pub trigger_id: Option<i64>,
}Expand description
A single manual trigger in Display & Video 360. Warning: Line Items using manual triggers no longer serve in Display & Video 360. This resource will sunset on August 1, 2023. Read our feature deprecation announcement for more information.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- manual triggers activate advertisers (response)
- manual triggers create advertisers (request|response)
- manual triggers deactivate advertisers (response)
- manual triggers get advertisers (response)
- manual triggers patch advertisers (request|response)
Fields
activation_duration_minutes: Option<i64>Required. The maximum duration of each activation in minutes. Must be between 1 and 360 inclusive. After this duration, the trigger will be automatically deactivated.
advertiser_id: Option<i64>Required. Immutable. The unique ID of the advertiser that the manual trigger belongs to.
display_name: Option<String>Required. The display name of the manual trigger. Must be UTF-8 encoded with a maximum size of 240 bytes.
latest_activation_time: Option<DateTime<Utc>>Output only. The timestamp of the trigger’s latest activation.
name: Option<String>Output only. The resource name of the manual trigger.
state: Option<String>Output only. The state of the manual trigger. Will be set to the INACTIVE state upon creation.
trigger_id: Option<i64>Output only. The unique ID of the manual trigger.