pub struct NegativeKeywordListAssignedTargetingOptionDetails {
pub negative_keyword_list_id: Option<i64>,
}Expand description
Targeting details for negative keyword list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_NEGATIVE_KEYWORD_LIST.
This type is not used in any activity, and only used as part of another schema.
Fields
negative_keyword_list_id: Option<i64>Required. ID of the negative keyword list. Should refer to the negative_keyword_list_id field of a NegativeKeywordList resource.