pub struct OnScreenPositionAssignedTargetingOptionDetails {
pub ad_type: Option<String>,
pub on_screen_position: Option<String>,
pub targeting_option_id: Option<String>,
}Expand description
On screen position targeting option details. This will be populated in the on_screen_position_details field when targeting_type is TARGETING_TYPE_ON_SCREEN_POSITION.
This type is not used in any activity, and only used as part of another schema.
Fields
ad_type: Option<String>Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * AD_TYPE_DISPLAY, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_DISPLAY_DEFAULT. * AD_TYPE_VIDEO, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_VIDEO_DEFAULT.
on_screen_position: Option<String>Output only. The on screen position.
targeting_option_id: Option<String>Required. The targeting_option_id field when targeting_type is TARGETING_TYPE_ON_SCREEN_POSITION.