pub struct ParentalStatusAssignedTargetingOptionDetails {
pub parental_status: Option<String>,
pub targeting_option_id: Option<String>,
}Expand description
Details for assigned parental status targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_PARENTAL_STATUS.
This type is not used in any activity, and only used as part of another schema.
Fields
parental_status: Option<String>Required. The parental status of the audience.
targeting_option_id: Option<String>Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_PARENTAL_STATUS.