Struct google_displayvideo1::api::Partner[][src]

pub struct Partner {
    pub ad_server_config: Option<PartnerAdServerConfig>,
    pub data_access_config: Option<PartnerDataAccessConfig>,
    pub display_name: Option<String>,
    pub entity_status: Option<String>,
    pub exchange_config: Option<ExchangeConfig>,
    pub general_config: Option<PartnerGeneralConfig>,
    pub name: Option<String>,
    pub partner_id: Option<String>,
    pub update_time: Option<String>,
}

A single partner in Display & Video 360 (DV360).

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

ad_server_config: Option<PartnerAdServerConfig>

Ad server related settings of the partner.

data_access_config: Option<PartnerDataAccessConfig>

Settings that control how partner data may be accessed.

display_name: Option<String>

The display name of the partner. Must be UTF-8 encoded with a maximum size of 240 bytes.

entity_status: Option<String>

Output only. The status of the partner.

exchange_config: Option<ExchangeConfig>

Settings that control which exchanges are enabled for the partner.

general_config: Option<PartnerGeneralConfig>

General settings of the partner.

name: Option<String>

Output only. The resource name of the partner.

partner_id: Option<String>

Output only. The unique ID of the partner. Assigned by the system.

update_time: Option<String>

Output only. The timestamp when the partner was last updated. Assigned by the system.