pub struct PartnerCost {
pub cost_type: Option<String>,
pub fee_amount: Option<i64>,
pub fee_percentage_millis: Option<i64>,
pub fee_type: Option<String>,
pub invoice_type: Option<String>,
}Expand description
Settings that control a partner cost. A partner cost is any type of expense involved in running a campaign, other than the costs of purchasing impressions (which is called the media cost) and using third-party audience segment data (data fee). Some examples of partner costs include the fees for using DV360, a third-party ad server, or a third-party ad serving verification service.
This type is not used in any activity, and only used as part of another schema.
Fields
cost_type: Option<String>Required. The type of the partner cost.
fee_amount: Option<i64>The CPM fee amount in micros of advertiser’s currency. Applicable when the fee_type is PARTNER_FEE_TYPE_CPM_FEE. Must be greater than or equal to 0. For example, for 1.5 standard unit of the advertiser’s currency, set this field to 1500000.
fee_percentage_millis: Option<i64>The media fee percentage in millis (1/1000 of a percent). Applicable when the fee_type is PARTNER_FEE_TYPE_MEDIA_FEE. Must be greater than or equal to 0. For example: 100 represents 0.1%.
fee_type: Option<String>Required. The fee type for this partner cost.
invoice_type: Option<String>The invoice type for this partner cost. * Required when cost_type is one of: - PARTNER_COST_TYPE_ADLOOX - PARTNER_COST_TYPE_DOUBLE_VERIFY - PARTNER_COST_TYPE_INTEGRAL_AD_SCIENCE. * Output only for other types.