pub struct PartnerRevenueModel {
pub markup_amount: Option<i64>,
pub markup_type: Option<String>,
}Expand description
Settings that control how partner revenue is calculated.
This type is not used in any activity, and only used as part of another schema.
Fields
markup_amount: Option<i64>Required. The markup amount of the partner revenue model. Must be greater than or equal to 0. * When the markup_type is set to be PARTNER_REVENUE_MODEL_MARKUP_TYPE_CPM, this field represents the CPM markup in micros of advertiser’s currency. For example, 1500000 represents 1.5 standard units of the currency. * When the markup_type is set to be PARTNER_REVENUE_MODEL_MARKUP_TYPE_MEDIA_COST_MARKUP, this field represents the media cost percent markup in millis. For example, 100 represents 0.1% (decimal 0.001). * When the markup_type is set to be PARTNER_REVENUE_MODEL_MARKUP_TYPE_TOTAL_MEDIA_COST_MARKUP, this field represents the total media cost percent markup in millis. For example, 100 represents 0.1% (decimal 0.001).
markup_type: Option<String>Required. The markup type of the partner revenue model.