PoiAssignedTargetingOptionDetails

Struct PoiAssignedTargetingOptionDetails 

pub struct PoiAssignedTargetingOptionDetails {
    pub display_name: Option<String>,
    pub latitude: Option<f64>,
    pub longitude: Option<f64>,
    pub proximity_radius_amount: Option<f64>,
    pub proximity_radius_unit: Option<String>,
    pub targeting_option_id: Option<String>,
}
Details for assigned POI targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_POI.

This type is not used in any activity, and only used as part of another schema.

Fields

display_name: Option<String>

Output only. The display name of a POI, e.g. “Times Square”, “Space Needle”, followed by its full address if available.

latitude: Option<f64>

Output only. Latitude of the POI rounding to 6th decimal place.

longitude: Option<f64>

Output only. Longitude of the POI rounding to 6th decimal place.

proximity_radius_amount: Option<f64>

Required. The radius of the area around the POI that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is DISTANCE_UNIT_MILES.

proximity_radius_unit: Option<String>

Required. The unit of distance by which the targeting radius is measured.

targeting_option_id: Option<String>

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_POI. Accepted POI targeting option IDs can be retrieved using targetingTypes.targetingOptions.search. If targeting a specific latitude/longitude coordinate removed from an address or POI name, you can generate the necessary targeting option ID by rounding the desired coordinate values to the 6th decimal place, removing the decimals, and concatenating the string values separated by a semicolon. For example, you can target the latitude/longitude pair of 40.7414691, -74.003387 using the targeting option ID “40741469;-74003387”. Upon creation, this field value will be updated to append a semicolon and alphanumerical hash value if only latitude/longitude coordinates are provided.