pub struct PrismaCpeCode {
pub prisma_client_code: Option<String>,
pub prisma_estimate_code: Option<String>,
pub prisma_product_code: Option<String>,
}Expand description
Google Payments Center supports searching and filtering on the component fields of this code.
This type is not used in any activity, and only used as part of another schema.
Fields
prisma_client_code: Option<String>The Prisma client code.
prisma_estimate_code: Option<String>The Prisma estimate code.
prisma_product_code: Option<String>The Prisma product code.