pub struct SdfdownloadtaskMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on sdfdownloadtask resources.
It is not used directly, but through the DisplayVideo hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_displayvideo1 as displayvideo1;
use displayvideo1::{DisplayVideo, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = DisplayVideo::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `create(...)` and `operations_get(...)`
// to build up your call.
let rb = hub.sdfdownloadtasks();Implementations
Sourceimpl<'a, C> SdfdownloadtaskMethods<'a, C>
impl<'a, C> SdfdownloadtaskMethods<'a, C>
Sourcepub fn operations_get(
&self,
name: &str,
) -> SdfdownloadtaskOperationGetCall<'a, C>
pub fn operations_get( &self, name: &str, ) -> SdfdownloadtaskOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of an asynchronous SDF download task operation. Clients should poll this method at intervals of 30 seconds.
Arguments
name- The name of the operation resource.
Sourcepub fn create(
&self,
request: CreateSdfDownloadTaskRequest,
) -> SdfdownloadtaskCreateCall<'a, C>
pub fn create( &self, request: CreateSdfDownloadTaskRequest, ) -> SdfdownloadtaskCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates an SDF Download Task. Returns an Operation. An SDF Download Task is a long-running, asynchronous operation. The metadata type of this operation is SdfDownloadTaskMetadata. If the request is successful, the response type of the operation is SdfDownloadTask. The response will not include the download files, which must be retrieved with media.download. The state of operation can be retrieved with sdfdownloadtasks.operations.get. Any errors can be found in the error.message. Note that error.details is expected to be empty.
Arguments
request- No description provided.