Struct google_displayvideo1::api::SearchTargetingOptionsResponse[][src]

pub struct SearchTargetingOptionsResponse {
    pub next_page_token: Option<String>,
    pub targeting_options: Option<Vec<TargetingOption>>,
}

Response message for SearchTargetingOptionsResponse.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

next_page_token: Option<String>

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to SearchTargetingOptions method to retrieve the next page of results.

targeting_options: Option<Vec<TargetingOption>>

The list of targeting options that match the search criteria. This list will be absent if empty.