pub struct TargetingExpansionConfig {
pub exclude_first_party_audience: Option<bool>,
pub targeting_expansion_level: Option<String>,
}Expand description
Settings that control the optimized targeting settings of the line item.
This type is not used in any activity, and only used as part of another schema.
Fields
exclude_first_party_audience: Option<bool>Whether to exclude first-party audiences from use in targeting expansion. This field was deprecated with the launch of optimized targeting. This field will be set to false. If this field is set to true when deprecated, all positive first-party audience targeting assigned to this line item will be replaced with negative targeting of the same first-party audiences to ensure the continued exclusion of those audiences.
targeting_expansion_level: Option<String>Required. Whether optimized targeting is turned on. This field supports the following values: * NO_EXPANSION: optimized targeting is turned off * LEAST_EXPANSION: optimized targeting is turned on If this field is set to any other value, it will automatically be set to LEAST_EXPANSION. NO_EXPANSION will be the default value for the field and will be automatically assigned if you do not set the field.