Struct google_displayvideo1::api::TargetingOption [−][src]
Represents a single targeting option, which is a targetable concept in DV360.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- targeting options get targeting types (response)
Fields
age_range_details: Option<AgeRangeTargetingOptionDetails>Age range details.
app_category_details: Option<AppCategoryTargetingOptionDetails>App category details.
Authorized seller status resource details.
browser_details: Option<BrowserTargetingOptionDetails>Browser details.
carrier_and_isp_details: Option<CarrierAndIspTargetingOptionDetails>Carrier and ISP details.
category_details: Option<CategoryTargetingOptionDetails>Category resource details.
content_instream_position_details: Option<ContentInstreamPositionTargetingOptionDetails>Content instream position details.
content_outstream_position_details: Option<ContentOutstreamPositionTargetingOptionDetails>Content outstream position details.
device_make_model_details: Option<DeviceMakeModelTargetingOptionDetails>Device make and model resource details.
device_type_details: Option<DeviceTypeTargetingOptionDetails>Device type details.
digital_content_label_details: Option<DigitalContentLabelTargetingOptionDetails>Digital content label details.
environment_details: Option<EnvironmentTargetingOptionDetails>Environment details.
exchange_details: Option<ExchangeTargetingOptionDetails>Exchange details.
gender_details: Option<GenderTargetingOptionDetails>Gender details.
geo_region_details: Option<GeoRegionTargetingOptionDetails>Geographic region resource details.
household_income_details: Option<HouseholdIncomeTargetingOptionDetails>Household income details.
language_details: Option<LanguageTargetingOptionDetails>Language resource details.
name: Option<String>Output only. The resource name for this targeting option.
on_screen_position_details: Option<OnScreenPositionTargetingOptionDetails>On screen position details.
operating_system_details: Option<OperatingSystemTargetingOptionDetails>Operating system resources details.
parental_status_details: Option<ParentalStatusTargetingOptionDetails>Parental status details.
sensitive_category_details: Option<SensitiveCategoryTargetingOptionDetails>Sensitive Category details.
sub_exchange_details: Option<SubExchangeTargetingOptionDetails>Sub-exchange details.
targeting_option_id: Option<String>Output only. A unique identifier for this targeting option. The tuple {targeting_type, targeting_option_id} will be unique.
targeting_type: Option<String>Output only. The type of this targeting option.
user_rewarded_content_details: Option<UserRewardedContentTargetingOptionDetails>User rewarded content details.
video_player_size_details: Option<VideoPlayerSizeTargetingOptionDetails>Video player size details.
viewability_details: Option<ViewabilityTargetingOptionDetails>Viewability resource details.