Struct google_displayvideo1::api::Transcode [−][src]
Represents information about the transcoded audio or video file.
This type is not used in any activity, and only used as part of another schema.
Fields
audio_bit_rate_kbps: Option<String>The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second.
audio_sample_rate_hz: Option<String>The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz.
bit_rate_kbps: Option<String>The transcoding bit rate of the transcoded video, in kilobits per second.
dimensions: Option<Dimensions>The dimensions of the transcoded video.
file_size_bytes: Option<String>The size of the transcoded file, in bytes.
frame_rate: Option<f32>The frame rate of the transcoded video, in frames per second.
mime_type: Option<String>The MIME type of the transcoded file.
name: Option<String>The name of the transcoded file.
transcoded: Option<bool>Indicates if the transcoding was successful.