Struct google_displayvideo1::api::UserListCall [−][src]
Lists users that are accessible to the current user. If two users have user roles on the same partner or advertiser, they can access each other.
A builder for the list method supported by a user resource.
It is not used directly, but through a UserMethods instance.
Example
Instantiate a resource method builder
// You can configure optional parameters by calling the respective setters at will, and // execute the final call using `doit()`. // Values shown here are possibly random and not representative ! let result = hub.users().list() .page_token("gubergren") .page_size(-94) .order_by("ipsum") .filter("kasd") .doit().await;
Implementations
impl<'a> UserListCall<'a>[src]
pub async fn doit(self) -> Result<(Response<Body>, ListUsersResponse)>[src]
Perform the operation you have build so far.
pub fn page_token(self, new_value: &str) -> UserListCall<'a>[src]
A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to ListUsers method. If not specified, the first page of results will be returned.
Sets the page token query property to the given value.
pub fn page_size(self, new_value: i32) -> UserListCall<'a>[src]
Requested page size. Must be between 1 and 100. If unspecified will default to 100.
Sets the page size query property to the given value.
pub fn order_by(self, new_value: &str) -> UserListCall<'a>[src]
Field by which to sort the list. Acceptable values are: * displayName (default) The default sorting order is ascending. To specify descending order for a field, a suffix “desc” should be added to the field name. For example, displayName desc.
Sets the order by query property to the given value.
pub fn filter(self, new_value: &str) -> UserListCall<'a>[src]
Allows filtering by user properties. Supported syntax: * Filter expressions are made up of one or more restrictions. * Restrictions can be combined by the logical operator AND. * A restriction has the form of {field} {operator} {value}. * The operator must be CONTAINS (:) or EQUALS (=). * The operator must be CONTAINS (:) for the following fields: - displayName - email * The operator must be EQUALS (=) for the following fields: - assignedUserRole.userRole - assignedUserRole.partnerId - assignedUserRole.advertiserId - assignedUserRole.entityType: A synthetic field of AssignedUserRole used for filtering. Identifies the type of entity to which the user role is assigned. Valid values are Partner and Advertiser. - assignedUserRole.parentPartnerId: A synthetic field of AssignedUserRole used for filtering. Identifies the parent partner of the entity to which the user role is assigned.“ Examples: * The user with displayName containing foo: displayName:"foo" * The user with email containing bar: email:"bar" * All users with standard user roles: assignedUserRole.userRole="STANDARD" * All users with user roles for partner 123: assignedUserRole.partnerId="123" * All users with user roles for advertiser 123: assignedUserRole.advertiserId="123" * All users with partner level user roles: entityType="PARTNER" * All users with user roles for partner 123 and advertisers under partner 123: parentPartnerId="123" The length of this field should be no more than 500 characters.
Sets the filter query property to the given value.
pub fn delegate(self, new_value: &'a mut dyn Delegate) -> UserListCall<'a>[src]
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.
Sets the delegate property to the given value.
pub fn param<T>(self, name: T, value: T) -> UserListCall<'a> where
T: AsRef<str>, [src]
T: AsRef<str>,
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known parameters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- $.xgafv (query-string) - V1 error format.
- access_token (query-string) - OAuth access token.
- alt (query-string) - Data format for response.
- callback (query-string) - JSONP
- fields (query-string) - Selector specifying which fields to include in a partial response.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
- upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
pub fn add_scope<T, S>(self, scope: T) -> UserListCall<'a> where
T: Into<Option<S>>,
S: AsRef<str>, [src]
T: Into<Option<S>>,
S: AsRef<str>,
Identifies the authorization scope for the method you are building.
Use this method to actively specify which scope should be used, instead the default Scope variant
Scope::DisplayVideoUserManagement.
The scope will be added to a set of scopes. This is important as one can maintain access
tokens for more than one scope.
If None is specified, then all scopes will be removed and no default scope will be used either.
In that case, you have to specify your API-key using the key parameter (see the param()
function for details).
Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.