pub struct VideoPlayerSizeAssignedTargetingOptionDetails {
pub targeting_option_id: Option<String>,
pub video_player_size: Option<String>,
}Expand description
Video player size targeting option details. This will be populated in the video_player_size_details field when targeting_type is TARGETING_TYPE_VIDEO_PLAYER_SIZE. Explicitly targeting all options is not supported. Remove all video player size targeting options to achieve this effect.
This type is not used in any activity, and only used as part of another schema.
Fields
targeting_option_id: Option<String>Required. The targeting_option_id field when targeting_type is TARGETING_TYPE_VIDEO_PLAYER_SIZE.
video_player_size: Option<String>Required. The video player size.