Struct google_displayvideo1::api::BulkEditPartnerAssignedTargetingOptionsResponse [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
created_assigned_targeting_options: Option<Vec<AssignedTargetingOption>>The list of assigned targeting options that have been successfully created. This list will be absent if empty.