Struct google_displayvideo1::api::CreateAssignedTargetingOptionsRequest [−][src]
A request listing which assigned targeting options of a given targeting type should be created and added.
This type is not used in any activity, and only used as part of another schema.
Fields
assigned_targeting_options: Option<Vec<AssignedTargetingOption>>Required. The assigned targeting options to create and add.
targeting_type: Option<String>Required. Identifies the type of this assigned targeting option.