Struct google_displayvideo1::api::ListCustomBiddingAlgorithmsResponse [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list custom bidding algorithms (response)
Fields
custom_bidding_algorithms: Option<Vec<CustomBiddingAlgorithm>>The list of custom bidding algorithms. This list will be absent if empty.
next_page_token: Option<String>A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCustomBiddingAlgorithmsRequest method to retrieve the next page of results. If this field is null, it means this is the last page.