Struct google_displayvideo1::api::PerformanceGoal [−][src]
Settings that control the performance goal of a campaign or insertion order.
This type is not used in any activity, and only used as part of another schema.
Fields
performance_goal_amount_micros: Option<String>The goal amount, in micros of the advertiser’s currency. Applicable when performance_goal_type is one of: * PERFORMANCE_GOAL_TYPE_CPM * PERFORMANCE_GOAL_TYPE_CPC * PERFORMANCE_GOAL_TYPE_CPA * PERFORMANCE_GOAL_TYPE_CPIAVC * PERFORMANCE_GOAL_TYPE_VCPM For example 1500000 represents 1.5 standard units of the currency.
performance_goal_percentage_micros: Option<String>The decimal representation of the goal percentage in micros. Applicable when performance_goal_type is one of: * PERFORMANCE_GOAL_TYPE_CTR * PERFORMANCE_GOAL_TYPE_VIEWABILITY * PERFORMANCE_GOAL_TYPE_CLICK_CVR * PERFORMANCE_GOAL_TYPE_IMPRESSION_CVR * PERFORMANCE_GOAL_TYPE_VTR * PERFORMANCE_GOAL_TYPE_AUDIO_COMPLETION_RATE * PERFORMANCE_GOAL_TYPE_VIDEO_COMPLETION_RATE For example, 70000 represents 7% (decimal 0.07).
performance_goal_string: Option<String>A key performance indicator (KPI) string, which can be empty. Must be UTF-8 encoded with a length of no more than 100 characters. Applicable when performance_goal_type is set to PERFORMANCE_GOAL_TYPE_OTHER.
performance_goal_type: Option<String>Required. The type of the performance goal.