Struct google_displayvideo1::api::SearchTargetingOptionsRequest [−][src]
Request message for SearchTargetingOptions.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- targeting options search targeting types (request)
Fields
advertiser_id: Option<String>Required. The Advertiser this request is being made in the context of.
geo_region_search_terms: Option<GeoRegionSearchTerms>Search terms for geo region targeting options. Can only be used when targeting_type is TARGETING_TYPE_GEO_REGION.
page_size: Option<i32>Requested page size. Must be between 1 and 100. If unspecified will default to 100. Returns error code INVALID_ARGUMENT if an invalid value is specified.
page_token: Option<String>A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to SearchTargetingOptions method. If not specified, the first page of results will be returned.