Struct google_displayvideo1::api::TargetingTypeMethods [−][src]
A builder providing access to all methods supported on targetingType resources.
It is not used directly, but through the DisplayVideo hub.
Example
Instantiate a resource builder
extern crate hyper; extern crate hyper_rustls; extern crate yup_oauth2 as oauth2; extern crate google_displayvideo1 as displayvideo1; use std::default::Default; use oauth2; use displayvideo1::DisplayVideo; let secret: oauth2::ApplicationSecret = Default::default(); let auth = yup_oauth2::InstalledFlowAuthenticator::builder( secret, yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect, ).build().await.unwrap(); let mut hub = DisplayVideo::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth); // Usually you wouldn't bind this to a variable, but keep calling *CallBuilders* // like `targeting_options_get(...)`, `targeting_options_list(...)` and `targeting_options_search(...)` // to build up your call. let rb = hub.targeting_types();
Implementations
impl<'a> TargetingTypeMethods<'a>[src]
pub fn targeting_options_get(
&self,
targeting_type: &str,
targeting_option_id: &str
) -> TargetingTypeTargetingOptionGetCall<'a>[src]
&self,
targeting_type: &str,
targeting_option_id: &str
) -> TargetingTypeTargetingOptionGetCall<'a>
Create a builder to help you perform the following task:
Gets a single targeting option.
Arguments
targetingType- Required. The type of targeting option to retrieve.targetingOptionId- Required. The ID of the of targeting option to retrieve.
pub fn targeting_options_list(
&self,
targeting_type: &str
) -> TargetingTypeTargetingOptionListCall<'a>[src]
&self,
targeting_type: &str
) -> TargetingTypeTargetingOptionListCall<'a>
Create a builder to help you perform the following task:
Lists targeting options of a given type.
Arguments
targetingType- Required. The type of targeting option to be listed.
pub fn targeting_options_search(
&self,
request: SearchTargetingOptionsRequest,
targeting_type: &str
) -> TargetingTypeTargetingOptionSearchCall<'a>[src]
&self,
request: SearchTargetingOptionsRequest,
targeting_type: &str
) -> TargetingTypeTargetingOptionSearchCall<'a>
Create a builder to help you perform the following task:
Searches for targeting options of a given type based on the given search terms.
Arguments
request- No description provided.targetingType- Required. The type of targeting options to retrieve. Accepted values are: *TARGETING_TYPE_GEO_REGION