pub struct Transcode {
pub audio_bit_rate_kbps: Option<i64>,
pub audio_sample_rate_hz: Option<i64>,
pub bit_rate_kbps: Option<i64>,
pub dimensions: Option<Dimensions>,
pub file_size_bytes: Option<i64>,
pub frame_rate: Option<f32>,
pub mime_type: Option<String>,
pub name: Option<String>,
pub transcoded: Option<bool>,
}Expand description
Represents information about the transcoded audio or video file.
This type is not used in any activity, and only used as part of another schema.
Fields
audio_bit_rate_kbps: Option<i64>Optional. The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second.
audio_sample_rate_hz: Option<i64>Optional. The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz.
bit_rate_kbps: Option<i64>Optional. The transcoding bit rate of the transcoded video, in kilobits per second.
dimensions: Option<Dimensions>Optional. The dimensions of the transcoded video.
file_size_bytes: Option<i64>Optional. The size of the transcoded file, in bytes.
frame_rate: Option<f32>Optional. The frame rate of the transcoded video, in frames per second.
mime_type: Option<String>Optional. The MIME type of the transcoded file.
name: Option<String>Optional. The name of the transcoded file.
transcoded: Option<bool>Optional. Indicates if the transcoding was successful.